@@ -1,6 +1,10 @@
 import pypandoc
 from packaging import version
 from rich import print
+from markdown_it import MarkdownIt
+
+
+md = MarkdownIt()
 
 
 def print_pandoc_info():
@@ -15,6 +19,10 @@ def print_pandoc_info():
 
 
 def convert(source: str, target_format: str, source_format: str = "md") -> str:
+
+    if source_format == "md" and target_format == "html":
+        return md.render(source)
+
     if source_format == "mediawiki":
         extra_args = ["--from", "mediawiki", "--to", "html"]
     else:
